/*
 * Copyright (c)  2007 - 2020 by inovat
 * innovative systeme - verkehr - tunnel - technik,
 * Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject
 *
 * de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Diese Datei ist Teil von de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject.
 *
 * de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject ist Freie Software: Sie können es unter den Bedingungen
 * der GNU General Public License, wie von der Free Software Foundation,
 * Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren
 * veröffentlichten Version, weiterverbreiten und/oder modifizieren.
 *
 * de.bsvrz.sys.funclib.kbgen.ProxyConfigurationObject wird in der Hoffnung, dass es nützlich sein wird, aber
 * OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
 * Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
 * Siehe die GNU General Public License für weitere Details.
 *
 * Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 * Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * An der Krautwiese 37
 * D-53783 Eitorf
 * +49 (0)2243 8464 193
 * info@inovat.de
 * www.inovat.de
 */

package de.bsvrz.sys.funclib.kbgen;

import de.bsvrz.dav.daf.main.config.SystemObjectType;
import java.util.ArrayList;
import java.util.List;

/**
 * Repräsentiert ein Stellvertreterobjekt für ein {@link de.bsvrz.dav.daf.main.config.ConfigurationObject}.
 * <p>
 * Dieses Stellvertreterobjekt hält alle Informationen eines {@link de.bsvrz.dav.daf.main.config.ConfigurationObject} einschließlich der Daten der
 * konfigurierenden Attributgruppen. Aus diesen Informationen wird dann über ein Objekt der Klasse {@link ConfigAreaCreator} ein Konfigurationsbereich
 * erzeugt. Das Proxyobjekt enthält damit alle Informatioen, die später (nach der Erzeugung des Konfigurationsbereichs) aus der Konfiguration zu dem
 * entsprechenden Objekt ermittelt werden können.
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author Dipl.-Ing. Hans Christian Kniß (HCK)
 */

public class ProxyConfigurationObject implements Cloneable {

    /** Die PID des zu erzeugenden ProxyObjekts. */
    private final String _pid;

    /** Der Name des zu erzeugenden ProxyObjekts. */
    private final String _name;

    /** Der Typ des zu erzeugenden ProxyObjekts. */
    private final SystemObjectType _type;

    /** Liste mit den Datenbeschreibungen am Objekt. */
    private final List<ProxyDataDescription> _proxyConfigurationDataList = new ArrayList<>();

    /** Liste mit den Mengen am Objekt. */
    private final List<ProxySetDescription> _proxySetList = new ArrayList<>();

// ------------------------------------------------------------------------
// KONSTRUKTOREN  (und vom Konstruktor verwende Methoden)
// ------------------------------------------------------------------------

    /**
     * Erzeugt ein Objekt vom Typ ProxyConfigurationObject.
     *
     * @param pid  Die PID des zu erzeugenden ProxyObjekts.
     * @param name Der Name des zu erzeugenden ProxyObjekts.
     * @param type Der Typ des zu erzeugenden ProxyObjekts.
     */
    public ProxyConfigurationObject(String pid, String name, SystemObjectType type) {
        _pid = pid;
        _name = name;
        _type = type;
    }

    /**
     * Getter für Eigenschaft '_pid'.
     *
     * @return Wert der Eigenschaft '_pid'.
     *
     * @see #_pid
     */

    public String getPid() {
        return _pid;
    }

    /**
     * Getter für Eigenschaft '_name'.
     *
     * @return Wert der Eigenschaft '_name'.
     *
     * @see #_name
     */

    public String getName() {
        return _name;
    }

    /**
     * Getter für Eigenschaft '_type'.
     *
     * @return Wert der Eigenschaft '_type'.
     *
     * @see #_type
     */

    public SystemObjectType getType() {
        return _type;
    }

    /**
     * Getter für Eigenschaft '_proxyConfigurationDataList'.
     *
     * @return Wert der Eigenschaft '_proxyConfigurationDataList'.
     *
     * @see #_proxyConfigurationDataList
     */

    public List<ProxyDataDescription> getProxyConfigurationDataList() {
        return _proxyConfigurationDataList;
    }

    /**
     * Getter für Eigenschaft '_proxySetList'.
     *
     * @return Wert der Eigenschaft '_proxySetList'.
     *
     * @see #_proxySetList
     */

    public List<ProxySetDescription> getProxySetList() {
        return _proxySetList;
    }

    /**
     * Gibt die String-Repräsentation dieses Objekts aus.
     * <p>
     * Die Formatierung der Ausgabe kann sich ändern und wird nicht garantiert.
     *
     * @return Aktueller Zustand der Klassenvariablen dieses Objekts.
     */
    public String toString() {
        return "ProxyConfigurationObject{" + "_pid='" + _pid + '\'' + ", _name='" + _name + '\'' + ", _type=" + _type +
               ", _proxyConfigurationDataList=" + _proxyConfigurationDataList + ", _proxySetList=" + _proxySetList + '}';
    }

    /**
     * Fügt einen Eintrag für eine Datenbeschreibung zur Liste der Datenbeschreibungen hinzu.
     *
     * @param proxyDataDescription Die hinzuzufügende Datenbeschreibung.
     */
    public final void addConfigurationData(ProxyDataDescription proxyDataDescription) {
        _proxyConfigurationDataList.add(proxyDataDescription);
    }

    /**
     * Fügt einen Eintrag für eine Menge zur Liste der Mengen hinzu.
     *
     * @param proxySetDescription Die hinzuzufügende Menge.
     */
    public final void addSet(ProxySetDescription proxySetDescription) {
        _proxySetList.add(proxySetDescription);
    }
}
