/*
 * Copyright (c)  2007 - 2020 by inovat
 * innovative systeme - verkehr - tunnel - technik,
 * Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.bsvrz.sys.funclib.kbgen.ProxySetDescription
 *
 * de.bsvrz.sys.funclib.kbgen.ProxySetDescription is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.sys.funclib.kbgen.ProxySetDescription is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.sys.funclib.kbgen.ProxySetDescription.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Diese Datei ist Teil von de.bsvrz.sys.funclib.kbgen.ProxySetDescription.
 *
 * de.bsvrz.sys.funclib.kbgen.ProxySetDescription ist Freie Software: Sie können es unter den Bedingungen
 * der GNU General Public License, wie von der Free Software Foundation,
 * Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren
 * veröffentlichten Version, weiterverbreiten und/oder modifizieren.
 *
 * de.bsvrz.sys.funclib.kbgen.ProxySetDescription wird in der Hoffnung, dass es nützlich sein wird, aber
 * OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
 * Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
 * Siehe die GNU General Public License für weitere Details.
 *
 * Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 * Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * An der Krautwiese 37
 * D-53783 Eitorf
 * +49 (0)2243 8464 193
 * info@inovat.de
 * www.inovat.de
 */

package de.bsvrz.sys.funclib.kbgen;

import java.util.List;

/**
 * Objekt, über den die (konfigurierenden) Mengen einer Attributgruppe für ein Objekt mit den Objektreferenzen innerhalb der Attributgruppe verknüpft
 * werden.
 * <p>
 * Erläuterung: Die Klasse {@link ConfigAreaCreator} erzeugt aus den ihr übergebenen Objekten vom Typ {@link ProxyConfigurationObject} die
 * Objektdefinitionen für einen Konfigurationsbereich im Datenkatalog. Dazu enthält ein {@link ProxyConfigurationObject} alle Informationen zu dem zu
 * erzeugenden Konfigurationsobjekt. Dies sind neben Typ, Name und Pid insbesondere die Informationen zu den konfigurierenden Attributgruppen und den
 * Mengen. Damit die Klasse {@link ConfigAreaCreator} die Informationen zu den konfigurierenden Attributgruppen genenerisch ermitteln kann, halt ein
 * {@link ProxyConfigurationObject} zu jeder konfigurierenden Attributgruppe die Daten in Form einer {@link de.bsvrz.dav.daf.main.Data} Struktur, über
 * die generisch iteriert werden kann. Das Problem besteht nun darin, dass Objektreferenzen in einer solchen {@link de.bsvrz.dav.daf.main.Data}
 * Struktur bei der Erstellung des {@link ProxyConfigurationObject} nicht eingetragen werden können, da dass referenzierte Objekt i. d. R. noch gar
 * nicht in der Konfiguration verfügbar ist. Der Versuch eine solche Referenz anzulegen führt deshalb zu einem Fehler. Aus diesem Grund wird zu einem
 * {@link de.bsvrz.dav.daf.main.Data} Objekt zusätzlich eine Liste mit den Pid der zu referenzierenden Objekte mitgeführt, wobei die Reihenfolge der
 * Einträge in der Liste der Reihenfolge der Objektreferenzen im {@link de.bsvrz.dav.daf.main.Data} Objekt entspricht. Bei der Auswertung der
 * Informationen durch die Klasse {@link ConfigAreaCreator} ermittelt diese dann den Wert einer Referenz nicht aus dem {@link
 * de.bsvrz.dav.daf.main.Data} Objekt, sondern aus dem entsprechenden Eintrag der Liste.
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author Dipl.-Ing. Hans Christian Kniß (HCK)
 */

public class ProxySetDescription {

    /** Liste der Pids mit Elementen der Menge. */
    private final List<String> _elements;

    /** Name der Menge. */
    private final String _name;

    /**
     * Erzeugt eine Beschreibung der Menge an einem ProxyKonfigurationsobjekt.
     *
     * @param name     Name der Menge.
     * @param elements Liste der Pids mit Elementen der Menge.
     */
    public ProxySetDescription(String name, List<String> elements) {
        _name = name;
        _elements = elements;
    }

    /**
     * Liefert die Liste der Pids mit den Objektreferenzen.
     *
     * @return Liste der Pids mit den im {@link de.bsvrz.dav.daf.main.Data} Objekt fehlenden Objektreferenzen.
     */
    public List<String> getElements() {
        return _elements;
    }

    /**
     * Liefert das {@link de.bsvrz.dav.daf.main.Data} Objekt.
     *
     * @return {@link de.bsvrz.dav.daf.main.Data} Objekt mit nicht gesetzten Objektreferenzen.
     */
    public String getName() {
        return _name;
    }

// ------------------------------------------------------------------------
// KANONISCHE METHODEN
// ------------------------------------------------------------------------

    /**
     * Gibt die String-Repräsentation dieses Objekts aus.
     * <p>
     * Die Formatierung der Ausgabe kann sich ändern und wird nicht garantiert.
     *
     * @return Aktueller Zustand der Klassenvariablen dieses Objekts.
     */
    public String toString() {
        return "ProxySetDescription{" + "_elements=" + _elements + ", _name='" + _name + '\'' + '}';
    }
}


